==> haskell-libyaml-0.1.0.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libyaml
version: 0.1.0.0
id: libyaml-0.1.0.0-1CisoXQjzdk1SWhgk5hzI5
key: libyaml-0.1.0.0-1CisoXQjzdk1SWhgk5hzI5
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>
category: Text
abi: a6277b0b2bf104934f3fa073bf3c2947
exposed: True
exposed-modules:
    Text.Libyaml
hidden-modules: Paths_libyaml
import-dirs: /usr/lib/ghc-8.6.1/site-local/libyaml-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/libyaml-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/libyaml-0.1.0.0
hs-libraries: HSlibyaml-0.1.0.0-1CisoXQjzdk1SWhgk5hzI5
extra-libraries:
    yaml
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1-KVXSRHbsNfjAMraP9AIqVV
    resourcet-1.2.2-IgPyczYAdnHDPKGn1GTTIT
haddock-interfaces: /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html: /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libyaml-0.1.0.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libyaml
version: 0.1.0.0
id: libyaml-0.1.0.0-53ZuMrJvrfFCAiMelYr7fv
key: libyaml-0.1.0.0-53ZuMrJvrfFCAiMelYr7fv
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>
category: Text
abi: 4b2e14624eddbfedece7f0afa21ccf5f
exposed: True
exposed-modules:
    Text.Libyaml
hidden-modules: Paths_libyaml
import-dirs: /usr/lib/ghc-8.6.1/site-local/libyaml-0.1.0.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/libyaml-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/libyaml-0.1.0.0
hs-libraries: HSlibyaml-0.1.0.0-53ZuMrJvrfFCAiMelYr7fv
extra-libraries:
    yaml
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1-2hedDM8RkfyGc8ZcxJJZlx
    resourcet-1.2.2-JdORPBy4ztGDXSSlNDo2w5
haddock-interfaces: /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html: /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
